==> touhoulittlemaid-fabric-1.21.1-0.0.3-neo1.3.6-sources.jar: com/github/tartaricacid/touhoulittlemaid/datagen/tag/TagBlock.java <==
package com.github.tartaricacid.touhoulittlemaid.datagen.tag;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricTagProvider;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2960;
import net.minecraft.class_3481;
import net.minecraft.class_6862;
import net.minecraft.class_7225;
import net.minecraft.class_7924;
import java.util.concurrent.CompletableFuture;

public class TagBlock extends FabricTagProvider<class_2248> {
    public static final class_6862<class_2248> MAID_JUMP_FORBIDDEN_BLOCK = class_6862.method_40092(class_7924.field_41254, class_2960.method_60655(TouhouLittleMaid.MOD_ID, "maid_jump_forbidden_block"));

    public static final class_6862<class_2248> ALTAR_TORII = class_6862.method_40092(class_7924.field_41254, class_2960.method_60655(TouhouLittleMaid.MOD_ID, "altar_torii"));
    public static final class_6862<class_2248> ALTAR_PILLAR = class_6862.method_40092(class_7924.field_41254, class_2960.method_60655(TouhouLittleMaid.MOD_ID, "altar_pillar"));

    public TagBlock(FabricDataOutput output, CompletableFuture<class_7225.class_7874> lookupProvider) {
        super(output, class_7924.field_41254, lookupProvider);
    }

    @Override
    protected void method_10514(class_7225.class_7874 provider) {
        getOrCreateTagBuilder(MAID_JUMP_FORBIDDEN_BLOCK)
                .forceAddTag(class_3481.field_15495)
                .forceAddTag(class_3481.field_16584)
                .forceAddTag(class_3481.field_22414);

        getOrCreateTagBuilder(ALTAR_TORII).add(class_2246.field_10314,class_2246.field_10058).method_35922(class_2960.method_60654("biomesoplenty:redwood_planks"));
        getOrCreateTagBuilder(ALTAR_PILLAR).forceAddTag(class_3481.field_15475);
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.1.7-neo1.3.8-sources.jar: com/github/tartaricacid/touhoulittlemaid/datagen/tag/TagBlock.java <==
package com.github.tartaricacid.touhoulittlemaid.datagen.tag;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricTagProvider;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2960;
import net.minecraft.class_3481;
import net.minecraft.class_6862;
import net.minecraft.class_7225;
import net.minecraft.class_7923;
import net.minecraft.class_7924;
import java.util.concurrent.CompletableFuture;

public class TagBlock extends FabricTagProvider<class_2248> {
    public static final class_6862<class_2248> MAID_JUMP_FORBIDDEN_BLOCK = class_6862.method_40092(class_7924.field_41254, class_2960.method_60655(TouhouLittleMaid.MOD_ID, "maid_jump_forbidden_block"));

    public static final class_6862<class_2248> ALTAR_TORII = class_6862.method_40092(class_7924.field_41254, class_2960.method_60655(TouhouLittleMaid.MOD_ID, "altar_torii"));
    public static final class_6862<class_2248> ALTAR_PILLAR = class_6862.method_40092(class_7924.field_41254, class_2960.method_60655(TouhouLittleMaid.MOD_ID, "altar_pillar"));

    public static final class_6862<class_2248> CARRYON_BLOCK_BLACKLIST = class_6862.method_40092(class_7924.field_41254, class_2960.method_60655("carryon", "block_blacklist"));

    public TagBlock(FabricDataOutput output, CompletableFuture<class_7225.class_7874> lookupProvider) {
        super(output, class_7924.field_41254, lookupProvider);
    }

    @Override
    protected void method_10514(class_7225.class_7874 provider) {
        getOrCreateTagBuilder(MAID_JUMP_FORBIDDEN_BLOCK)
                .forceAddTag(class_3481.field_15495)
                .forceAddTag(class_3481.field_16584)
                .forceAddTag(class_3481.field_22414);

        getOrCreateTagBuilder(ALTAR_TORII).add(class_2246.field_10314, class_2246.field_10058).method_35922(class_2960.method_60654("biomesoplenty:redwood_planks"));
        getOrCreateTagBuilder(ALTAR_PILLAR).forceAddTag(class_3481.field_15475);

        var blacklist = getOrCreateTagBuilder(CARRYON_BLOCK_BLACKLIST);
        class_7923.field_41175.method_10235().stream().filter(id -> id.method_12836().equals(TouhouLittleMaid.MOD_ID))
                .forEach(id -> blacklist.add(class_7923.field_41175.method_10223(id)));
    }
}
